==> aws_cdk_aws_scheduler_alpha-2.162.1a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_scheduler_alpha_ScheduleExpression(p) {
}
function _aws_cdk_aws_scheduler_alpha_CronOptionsWithTimezone(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput(p) {
}
function _aws_cdk_aws_scheduler_alpha_ContextAttribute(p) {
}
function _aws_cdk_aws_scheduler_alpha_ISchedule(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleTargetProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.input))
            _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput(p.input);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_scheduler_alpha_TimeWindow(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.schedule))
            _aws_cdk_aws_scheduler_alpha_ScheduleExpression(p.schedule);
        if (!visitedObjects.has(p.target))
            _aws_cdk_aws_scheduler_alpha_IScheduleTarget(p.target);
        if (!visitedObjects.has(p.group))
            _aws_cdk_aws_scheduler_alpha_IGroup(p.group);
        if (!visitedObjects.has(p.targetOverrides))
            _aws_cdk_aws_scheduler_alpha_ScheduleTargetProps(p.targetOverrides);
        if (!visitedObjects.has(p.timeWindow))
            _aws_cdk_aws_scheduler_alpha_TimeWindow(p.timeWindow);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_scheduler_alpha_Schedule(p) {
}
function _aws_cdk_aws_scheduler_alpha_GroupProps(p) {
}
function _aws_cdk_aws_scheduler_alpha_IGroup(p) {
}
function _aws_cdk_aws_scheduler_alpha_Group(p) {
}
function _aws_cdk_aws_scheduler_alpha_IScheduleTarget(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleTargetConfig(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.input))
            _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput(p.input);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_scheduler_alpha_ScheduleExpression, _aws_cdk_aws_scheduler_alpha_CronOptionsWithTimezone, _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput, _aws_cdk_aws_scheduler_alpha_ContextAttribute, _aws_cdk_aws_scheduler_alpha_ISchedule, _aws_cdk_aws_scheduler_alpha_ScheduleTargetProps, _aws_cdk_aws_scheduler_alpha_TimeWindow, _aws_cdk_aws_scheduler_alpha_ScheduleProps, _aws_cdk_aws_scheduler_alpha_Schedule, _aws_cdk_aws_scheduler_alpha_GroupProps, _aws_cdk_aws_scheduler_alpha_IGroup, _aws_cdk_aws_scheduler_alpha_Group, _aws_cdk_aws_scheduler_alpha_IScheduleTarget, _aws_cdk_aws_scheduler_alpha_ScheduleTargetConfig };

==> aws_cdk_aws_scheduler_alpha-2.185.0a0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_scheduler_alpha_ScheduleExpression(p) {
}
function _aws_cdk_aws_scheduler_alpha_CronOptionsWithTimezone(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput(p) {
}
function _aws_cdk_aws_scheduler_alpha_ContextAttribute(p) {
}
function _aws_cdk_aws_scheduler_alpha_ISchedule(p) {
}
function _aws_cdk_aws_scheduler_alpha_TimeWindow(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.schedule))
            _aws_cdk_aws_scheduler_alpha_ScheduleExpression(p.schedule);
        if (!visitedObjects.has(p.target))
            _aws_cdk_aws_scheduler_alpha_IScheduleTarget(p.target);
        if ("group" in p)
            print("@aws-cdk/aws-scheduler-alpha.ScheduleProps#group", "Use `scheduleGroup` instead. `group` will be removed when this module is stabilized.");
        if (!visitedObjects.has(p.group))
            _aws_cdk_aws_scheduler_alpha_IGroup(p.group);
        if (!visitedObjects.has(p.scheduleGroup))
            _aws_cdk_aws_scheduler_alpha_IScheduleGroup(p.scheduleGroup);
        if (!visitedObjects.has(p.timeWindow))
            _aws_cdk_aws_scheduler_alpha_TimeWindow(p.timeWindow);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_scheduler_alpha_Schedule(p) {
}
function _aws_cdk_aws_scheduler_alpha_GroupProps(p) {
}
function _aws_cdk_aws_scheduler_alpha_IGroup(p) {
}
function _aws_cdk_aws_scheduler_alpha_Group(p) {
}
function _aws_cdk_aws_scheduler_alpha_IScheduleTarget(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleTargetConfig(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.input))
            _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput(p.input);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_scheduler_alpha_ScheduleGroupProps(p) {
}
function _aws_cdk_aws_scheduler_alpha_IScheduleGroup(p) {
}
function _aws_cdk_aws_scheduler_alpha_ScheduleGroup(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_scheduler_alpha_ScheduleExpression, _aws_cdk_aws_scheduler_alpha_CronOptionsWithTimezone, _aws_cdk_aws_scheduler_alpha_ScheduleTargetInput, _aws_cdk_aws_scheduler_alpha_ContextAttribute, _aws_cdk_aws_scheduler_alpha_ISchedule, _aws_cdk_aws_scheduler_alpha_TimeWindow, _aws_cdk_aws_scheduler_alpha_ScheduleProps, _aws_cdk_aws_scheduler_alpha_Schedule, _aws_cdk_aws_scheduler_alpha_GroupProps, _aws_cdk_aws_scheduler_alpha_IGroup, _aws_cdk_aws_scheduler_alpha_Group, _aws_cdk_aws_scheduler_alpha_IScheduleTarget, _aws_cdk_aws_scheduler_alpha_ScheduleTargetConfig, _aws_cdk_aws_scheduler_alpha_ScheduleGroupProps, _aws_cdk_aws_scheduler_alpha_IScheduleGroup, _aws_cdk_aws_scheduler_alpha_ScheduleGroup };
